# Documentation Vyro

Vyro combine Python DX avec un moteur d'exécution Rust pour des API hautes performances.

## Ce que vous pouvez faire

- Créez des API asynchrones avec `Vyro()`
- Exécuter des services avec `vyro run`
- Générer des contrats API avec OpenAPI
- Exploiter des services de production avec des primitives d'observabilité et de sécurité

## Commencez ici

1. Lisez [Installation](getting-started/installation.md)
2. Suivez [Quickstart](getting-started/quickstart.md)
3. Créez votre premier point de terminaison dans [First API](getting-started/first-api.md)